function [T,A]=parDtZV(Wn,DR,alpha)
%    [T,A]=parDtZV(Wn,DR,alpha)
%
%    Parametrization of the signal shaper with lumped and triangularly distributed delay
%
%    Input parameters:
%    Wn - natural frequency of the oscillatory mode to be compensated
%    DR - damping ratio of the mode to be compensated (0<=DR<1)
%    alpha - ratio between the length of the lumped delay and the overall
%            length of the shaper response T. The parameter options are 
%            alpha=0, 0.25, 0.5, 0.75, 1.
%
%    Output parameters:
%    T - overall length of the shaper response
%    A - gain of the first part of the response
%
%Created by Tomas Vyhlidal, Vladimir Kucera and Martin Hromcik
%
%http://www.cak.fs.cvut.cz/algorithms/shapers
%
%Reference: Tomas Vyhlidal, Vladimir Kucera, Martin Hromcik (2013) Zero vibration 
%shapers with distributed delays of various types, submitted to CDC2013, Zurich.


if ((sum(alpha==[0 0.25 0.5 0.75 1]))==1)&(DR<1)&(DR>=0)
    if alpha==1
        b=-DR*Wn;
        W=sqrt(Wn^2-b^2);
        T=pi/Wn;
        A=exp(-b/W*pi)/(1+exp(-b/W*pi)); 
    else
        ind=find(alpha==[0 0.25 0.5 0.75 1]);
        load DTZVpar;
        iz=max(find(DR>parZeta(ind,:)));
        kA=(parA(iz+1)-parA(iz))/(parZeta(ind,iz+1)-parZeta(ind,iz));
        A=parA(iz)+kA*(DR-parZeta(ind,iz));
        kT=(parTw0(ind,iz+1)-parTw0(ind,iz))/(parZeta(ind,iz+1)-parZeta(ind,iz));
        T=(parTw0(ind,iz)+kT*(DR-parZeta(ind,iz)))/Wn;
    end
else
    if sum(alpha==[0 0.25 0.5 0.75 1])~=1
        error('Parameter alpha should be selected from the set {0 0.25 0.5 0.75 1}')
    end
    if ~(DR<1&DR>=0)
        error('Relative damping should be 0<=DR<1')
    end
end
    

  